@@ -190,7 +190,8 @@ potentially taking a long time."
                               (if (re-search-backward "\\sw\\|\\s_" nil t)
                                   (forward-char))
                               (re-search-backward
-                               "\\(\\sw\\|\\s_\\)([0-9]+[A-Za-z]*\\=" nil t)
+                               "\\(\\sw\\|\\s_\\)([0-9]+[A-Za-z]*\\="
+			       (point-at-bol) t)
                               (skip-syntax-backward "w_")
                               (point))
 			    (progn
